<template>
  <div class="full-page bg">
    <div
      class="search-container"
      element-loading-text="数据加载中..."
      element-loading-spinner="el-icon-loading"
      element-loading-background="rgba(255,255,255, 0.5)"
      v-loading.fullscreen.lock="markLoading"
    >
      <el-form
        ref="form"
        :model="searchForm"
        label-width="auto"
        style="width: 100%"
      >
        <el-row :gutter="20">
          <el-col :span="5">
            <el-form-item label="区县">
              <el-input
                v-model="querys[1].value"
                clearable
                placeholder="请输入区县"
              >
              </el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="填报时间">
              <el-date-picker
                v-model="querys[0].value"
                :default-time="['00:00:00', '23:59:59']"
                align="right"
                clearable
                end-placeholder="结束日期"
                placeholder="请选择填报日期"
                start-placeholder="开始日期"
                type="datetimerange"
                value-format="yyyy-MM-dd HH:mm:ss"
              >
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-button
            icon="el-icon-search"
            type="primary"
            class="btn btn-plus"
            @click="handleSearch(1)"
          >
            搜索
          </el-button>
          <el-button
            icon="el-icon-setting"
            type="primary"
            class="btn btn-plus"
            style="margin-left: 20px;"
            @click="notificationFilling()"
          >
            通知填报
          </el-button>
        </el-row>
      </el-form>
    </div>
    <el-row :gutter="10" class="main-table-container flex">
      <el-col
        :span="24"
        class="table-container"
        ref="contentPanel"
        style="padding: 20px"
      >
        <div ref="btnPanel"></div>
        <div :style="{width: '100%', height: `${tableMaxHeight}` + 'px'}">
          <el-table
            stripe
            size="mini"
            v-loading="loading"
            ref="multipleSelection"
            :data="tableData"
            :max-height="tableMaxHeight"
            :style="{width: '100%'}"
          >
            <el-table-column
              type="index"
              width="60"
              label="序号"
              align="center"
            ></el-table-column>
            <el-table-column
              prop="unitName"
              min-width="100"
              show-overflow-tooltip
              label="区县名称"
              align="center"
            >
            </el-table-column>
            <el-table-column
              prop="eventNum"
              min-width="100"
              show-overflow-tooltip
              label="事件编号"
              align="center"
            >
            </el-table-column>
            <el-table-column
              align="center"
              label="通知时间"
              prop="sandDate"
              sortable
              show-overflow-tooltip
            >
            </el-table-column>
          </el-table>
        </div>
        <pagination
          ref="paginationPanel"
          style="margin-top: 10px"
          :pageResult="queryParam.pageBean"
          @size-change="handleSizeChange"
          @current-change="handleCurrentChange"
        />
      </el-col>
    </el-row>
    <county-dialog ref="countyDialog" @confirm="onConfirm"></county-dialog>
  </div>
</template>
<script>
import {TableMixin} from '@/mixins/tableMixin'
import countyApi from '@/api/ReformSituation/countyApi'
import pagination from '@/components/pagination/index.vue'
import countyDialog from '@/views/ReformSituation/components/countyDialog.vue'
export default {
  name: 'reformAndPromulgation',
  components: {
    countyDialog,
    pagination
  },
  mixins: [TableMixin],
  data() {
    return {
      markLoading: false,
      searchForm: {},
      loading: false,
      tableData: [
        {
          a: '万州区',
          b: '管理员',
          createTime: '2025-02-18',
          status: '1'
        }
      ],
      querys: [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'CREATE_TIME_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'unit_name_',
          relation: 'AND',
          value: ''
        },
      ],
      queryParam: {
        pageBean: {
          page: 1,
          pageSize: 20,
          total: 0
        }
      },
      // 弹层
      addDialogShow: false,
      addRow: {},
      addTitle: ''
    }
  },
  created() {
    this.getData()
  },
  methods: {
    handleSearch(page) {
      this.queryParam.querys = []
      this.querys.forEach(item => {
        if (item.value !== undefined) {
          this.queryParam.querys.push(item)
        }
      })
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.getData()
    },
    getData() {
      this.loading = true
      this.tableData = []
      this.queryParam.querys = this.querys
      countyApi.bizCountyReformMessageLog(this.queryParam,false).then(res => {
        if (res.rows) {
          this.tableData = res.rows
          this.queryParam.pageBean.page = res.page
          this.queryParam.pageBean.total = res.total
          this.$set(this.tableData)
          this.loading = false
        }
      })
    },
    //展示数量
    handleSizeChange(val) {
      this.queryParam.pageBean.pageSize = val
      this.handleSearch(1)
    },
    //表格页数
    handleCurrentChange(val) {
      this.queryParam.pageBean.page = val
      this.handleSearch(val)
    },
    notificationFilling() {
      this.$refs.countyDialog.upDate('区县填报')
    },
    onConfirm(){
      this.handleSearch(1)
    }
  }
}
</script>

<style lang="scss" scoped>
.common-tree-container {
  height: calc(100% - 70px);
  margin-top: 0.52083vw;
  padding: 1.04167vw 1.04167vw;
  background-color: #fff;
  position: relative;
  box-sizing: border-box;
  overflow-y: auto;
  border-radius: 20px;
  box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
  display: flex;
  align-items: center;

  i {
    font-size: 16px;
    margin-left: 5px;
    font-weight: 600;
    cursor: pointer;
  }
}

.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;

  &:nth-child(1) {
    margin-right: 5px;
  }

  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }

  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
    border-color: #2761ff;
  }

  /deep/ i,
  span {
    font-size: 14px;
  }
}
</style>